# Kynanlibs Library

Core library of [Naya-Pyro](https://github.com/naya1503/Naya-Pyro), a python based telegram userbot.

[![CodeFactor](https://www.codefactor.io/repository/github/opet321/pusing/badge)](https://www.codefactor.io/repository/github/opet321/pusing)
[![PyPI - Version](https://img.shields.io/pypi/v/py-Naya-Pyro?style=round)](https://pypi.org/project/kynaylibs)    
[![PyPI - Downloads](https://img.shields.io/pypi/dm/py-Naya-Pyro?label=DOWNLOADS&style=round)](https://pypi.org/project/kynaylibs)    
[![Maintenance](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://github.com/naya1503/Naya-Pyro/graphs/commit-activity)
[![Open Source Love svg2](https://badges.frapsoft.com/os/v2/open-source.svg?v=103)](https://github.com/naya1503/Naya-Pyro)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](https://makeapullrequest.com)

# Installation
```bash
pip3 install -U py-Ayra
```

# Documentation 
[![Documentation](https://img.shields.io/badge/Documentation-kynaylibs-blue)](http://ayra.tech/)



See more working plugins on [the offical repository](https://github.com/naya1503/Naya-Pyro)!

> Made with 💕 by [Kynan](https://t.me/Rizzvbss).    


# License
[![License](https://www.gnu.org/graphics/agplv3-155x51.png)](LICENSE)   
Ultroid is licensed under [GNU Affero General Public License](https://www.gnu.org/licenses/agpl-3.0.en.html) v3 or later.

# Credits
* [![Kynan-Devs](https://img.shields.io/static/v1?label=Kynan&message=devs&color=critical)](https://t.me/Rizzvbss)
